from box.functools import Decorator


class command(Decorator):

    # Public

    marker = '_clyde_command_command'

    def __call__(self, function):
        setattr(function, self.marker, True)
        return function